Enum ClassAsciiKind
enum ClassAsciiKind
The available ASCII character classes.
Variants
-
Alnum [0-9A-Za-z]-
Alpha [A-Za-z]-
Ascii [\x00-\x7F]-
Blank [ \t]-
Cntrl [\x00-\x1F\x7F]-
Digit [0-9]-
Graph [!-~]-
Lower [a-z]-
Print [ -~]-
Punct [!-/:-@\[-{-~]`-
Space [\t\n\v\f\r ]-
Upper [A-Z]-
Word [0-9A-Za-z_]-
Xdigit [0-9A-Fa-f]
Implementations
impl ClassAsciiKind
fn from_name(name: &str) -> Option<ClassAsciiKind>Return the corresponding ClassAsciiKind variant for the given name.
The name given should correspond to the lowercase version of the variant name. e.g.,
cntrlis the name forClassAsciiKind::Cntrl.If no variant with the corresponding name exists, then
Noneis returned.
impl Clone for ClassAsciiKind
fn clone(self: &Self) -> ClassAsciiKind
impl Debug for ClassAsciiKind
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for ClassAsciiKind
impl Freeze for ClassAsciiKind
impl PartialEq for ClassAsciiKind
fn eq(self: &Self, other: &ClassAsciiKind) -> bool
impl RefUnwindSafe for ClassAsciiKind
impl Send for ClassAsciiKind
impl StructuralPartialEq for ClassAsciiKind
impl Sync for ClassAsciiKind
impl Unpin for ClassAsciiKind
impl UnsafeUnpin for ClassAsciiKind
impl UnwindSafe for ClassAsciiKind
impl<T> Any for ClassAsciiKind
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ClassAsciiKind
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ClassAsciiKind
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for ClassAsciiKind
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for ClassAsciiKind
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for ClassAsciiKind
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for ClassAsciiKind
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ClassAsciiKind
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ClassAsciiKind
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>