Enum FlagsItemKind

enum FlagsItemKind

The kind of an item in a group of flags.

Variants

Negation

A negation operator applied to all subsequent flags in the enclosing group.

Flag(Flag)

A single flag in a group.

Implementations

impl FlagsItemKind

fn is_negation(self: &Self) -> bool

Returns true if and only if this item is a negation operator.

impl Clone for FlagsItemKind

fn clone(self: &Self) -> FlagsItemKind

impl Debug for FlagsItemKind

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for FlagsItemKind

impl Freeze for FlagsItemKind

impl PartialEq for FlagsItemKind

fn eq(self: &Self, other: &FlagsItemKind) -> bool

impl RefUnwindSafe for FlagsItemKind

impl Send for FlagsItemKind

impl StructuralPartialEq for FlagsItemKind

impl Sync for FlagsItemKind

impl Unpin for FlagsItemKind

impl UnsafeUnpin for FlagsItemKind

impl UnwindSafe for FlagsItemKind

impl<T> Any for FlagsItemKind

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for FlagsItemKind

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for FlagsItemKind

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for FlagsItemKind

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for FlagsItemKind

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for FlagsItemKind

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for FlagsItemKind

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for FlagsItemKind

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for FlagsItemKind

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>