LiteralKind

Enum LiteralKind 

pub enum LiteralKind {
    Verbatim,
    Meta,
    Superfluous,
    Octal,
    HexFixed(HexLiteralKind),
    HexBrace(HexLiteralKind),
    Special(SpecialLiteralKind),
}
The kind of a single literal expression.

Variants



Verbatim

The literal is written verbatim, e.g., a or .



Meta

The literal is written as an escape because it is otherwise a special regex meta character, e.g., \* or \[.



Superfluous

The literal is written as an escape despite the fact that the escape is unnecessary, e.g., \% or \/.



Octal

The literal is written as an octal escape, e.g., \141.



HexFixed(HexLiteralKind)

The literal is written as a hex code with a fixed number of digits depending on the type of the escape, e.g., \x61 or \u0061 or \U00000061.



HexBrace(HexLiteralKind)

The literal is written as a hex code with a bracketed number of digits. The only restriction is that the bracketed hex code must refer to a valid Unicode scalar value.



Special(SpecialLiteralKind)

The literal is written as a specially recognized escape, e.g., \f or \n.