Enum RepetitionRange
enum RepetitionRange
A range repetition operator.
Variants
-
Exactly(u32) {m}-
AtLeast(u32) {m,}-
Bounded(u32, u32) {m,n}
Implementations
impl RepetitionRange
fn is_valid(self: &Self) -> boolReturns true if and only if this repetition range is valid.
The only case where a repetition range is invalid is if it is bounded and its start is greater than its end.
impl Clone for RepetitionRange
fn clone(self: &Self) -> RepetitionRange
impl Debug for RepetitionRange
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for RepetitionRange
impl Freeze for RepetitionRange
impl PartialEq for RepetitionRange
fn eq(self: &Self, other: &RepetitionRange) -> bool
impl RefUnwindSafe for RepetitionRange
impl Send for RepetitionRange
impl StructuralPartialEq for RepetitionRange
impl Sync for RepetitionRange
impl Unpin for RepetitionRange
impl UnsafeUnpin for RepetitionRange
impl UnwindSafe for RepetitionRange
impl<T> Any for RepetitionRange
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for RepetitionRange
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for RepetitionRange
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for RepetitionRange
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for RepetitionRange
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for RepetitionRange
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for RepetitionRange
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for RepetitionRange
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for RepetitionRange
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>