Enum SpecialLiteralKind
enum SpecialLiteralKind
The type of a special literal.
A special literal is a special escape sequence recognized by the regex
parser, e.g., \f or \n.
Variants
-
Bell Bell, spelled
\a(\x07).-
FormFeed Form feed, spelled
\f(\x0C).-
Tab Tab, spelled
\t(\x09).-
LineFeed Line feed, spelled
\n(\x0A).-
CarriageReturn Carriage return, spelled
\r(\x0D).-
VerticalTab Vertical tab, spelled
\v(\x0B).-
Space Space, spelled
\(\x20). Note that this can only appear when parsing in verbose mode.
Implementations
impl Clone for SpecialLiteralKind
fn clone(self: &Self) -> SpecialLiteralKind
impl Debug for SpecialLiteralKind
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for SpecialLiteralKind
impl Freeze for SpecialLiteralKind
impl PartialEq for SpecialLiteralKind
fn eq(self: &Self, other: &SpecialLiteralKind) -> bool
impl RefUnwindSafe for SpecialLiteralKind
impl Send for SpecialLiteralKind
impl StructuralPartialEq for SpecialLiteralKind
impl Sync for SpecialLiteralKind
impl Unpin for SpecialLiteralKind
impl UnsafeUnpin for SpecialLiteralKind
impl UnwindSafe for SpecialLiteralKind
impl<T> Any for SpecialLiteralKind
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for SpecialLiteralKind
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for SpecialLiteralKind
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for SpecialLiteralKind
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for SpecialLiteralKind
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for SpecialLiteralKind
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for SpecialLiteralKind
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for SpecialLiteralKind
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for SpecialLiteralKind
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>