Struct CaptureName

struct CaptureName { ... }

A capture name.

This corresponds to the name itself between the angle brackets in, e.g., (?P<foo>expr).

Fields

span: Span

The span of this capture name.

name: String

The capture name.

index: u32

The capture index.

Implementations

impl Clone for CaptureName

fn clone(self: &Self) -> CaptureName

impl Debug for CaptureName

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for CaptureName

impl Freeze for CaptureName

impl PartialEq for CaptureName

fn eq(self: &Self, other: &CaptureName) -> bool

impl RefUnwindSafe for CaptureName

impl Send for CaptureName

impl StructuralPartialEq for CaptureName

impl Sync for CaptureName

impl Unpin for CaptureName

impl UnsafeUnpin for CaptureName

impl UnwindSafe for CaptureName

impl<T> Any for CaptureName

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for CaptureName

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for CaptureName

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for CaptureName

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for CaptureName

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for CaptureName

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for CaptureName

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for CaptureName

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for CaptureName

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>