Struct ClassSetRange

struct ClassSetRange { ... }

A single character class range in a set.

Fields

span: Span

The span of this range.

start: Literal

The start of this range.

end: Literal

The end of this range.

Implementations

impl ClassSetRange

fn is_valid(self: &Self) -> bool

Returns true if and only if this character class range is valid.

The only case where a range is invalid is if its start is greater than its end.

impl Clone for ClassSetRange

fn clone(self: &Self) -> ClassSetRange

impl Debug for ClassSetRange

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for ClassSetRange

impl Freeze for ClassSetRange

impl PartialEq for ClassSetRange

fn eq(self: &Self, other: &ClassSetRange) -> bool

impl RefUnwindSafe for ClassSetRange

impl Send for ClassSetRange

impl StructuralPartialEq for ClassSetRange

impl Sync for ClassSetRange

impl Unpin for ClassSetRange

impl UnsafeUnpin for ClassSetRange

impl UnwindSafe for ClassSetRange

impl<T> Any for ClassSetRange

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for ClassSetRange

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for ClassSetRange

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for ClassSetRange

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for ClassSetRange

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for ClassSetRange

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for ClassSetRange

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for ClassSetRange

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for ClassSetRange

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>