Struct regex_syntax::ast::Comment [−][src]
A comment from a regular expression with an associated span.
A regular expression can only contain comments when the x flag is
enabled.
Fields
span: SpanThe span of this comment, including the beginning # and ending \n.
comment: StringThe comment text, starting with the first character following the #
and ending with the last character preceding the \n.