Struct SetFlags

struct SetFlags { ... }

A group of flags that is not applied to a particular regular expression.

Fields

span: Span

The span of these flags, including the grouping parentheses.

flags: Flags

The actual sequence of flags.

Implementations

impl Clone for SetFlags

fn clone(self: &Self) -> SetFlags

impl Debug for SetFlags

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for SetFlags

impl Freeze for SetFlags

impl PartialEq for SetFlags

fn eq(self: &Self, other: &SetFlags) -> bool

impl RefUnwindSafe for SetFlags

impl Send for SetFlags

impl StructuralPartialEq for SetFlags

impl Sync for SetFlags

impl Unpin for SetFlags

impl UnsafeUnpin for SetFlags

impl UnwindSafe for SetFlags

impl<T> Any for SetFlags

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for SetFlags

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for SetFlags

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for SetFlags

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for SetFlags

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for SetFlags

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for SetFlags

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for SetFlags

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for SetFlags

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>