Struct WithComments

struct WithComments { ... }

An abstract syntax tree for a singular expression along with comments found.

Comments are not stored in the tree itself to avoid complexity. Each comment contains a span of precisely where it occurred in the original regular expression.

Fields

ast: Ast

The actual ast.

comments: Vec<Comment>

All comments found in the original regular expression.

Implementations

impl Clone for WithComments

fn clone(self: &Self) -> WithComments

impl Debug for WithComments

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for WithComments

impl Freeze for WithComments

impl PartialEq for WithComments

fn eq(self: &Self, other: &WithComments) -> bool

impl RefUnwindSafe for WithComments

impl Send for WithComments

impl StructuralPartialEq for WithComments

impl Sync for WithComments

impl Unpin for WithComments

impl UnsafeUnpin for WithComments

impl UnwindSafe for WithComments

impl<T> Any for WithComments

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for WithComments

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for WithComments

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for WithComments

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for WithComments

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for WithComments

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for WithComments

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for WithComments

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for WithComments

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>