Enum Dot

enum Dot

A type describing the different flavors of ..

This type is meant to be used with Hir::dot, which is a convenience routine for building HIR values derived from the . regex.

Variants

AnyChar

Matches the UTF-8 encoding of any Unicode scalar value.

This is equivalent to (?su:.) and also \p{any}.

AnyByte

Matches any byte value.

This is equivalent to (?s-u:.) and also (?-u:[\x00-\xFF]).

AnyCharExcept(char)

Matches the UTF-8 encoding of any Unicode scalar value except for the char given.

This is equivalent to using (?u-s:.) with the line terminator set to a particular ASCII byte. (Because of peculiarities in the regex engines, a line terminator must be a single byte. It follows that when UTF-8 mode is enabled, this single byte must also be a Unicode scalar value. That is, ti must be ASCII.)

(This and AnyCharExceptLF both exist because of legacy reasons. AnyCharExceptLF will be dropped in the next breaking change release.)

AnyCharExceptLF

Matches the UTF-8 encoding of any Unicode scalar value except for \n.

This is equivalent to (?u-s:.) and also [\p{any}--\n].

AnyCharExceptCRLF

Matches the UTF-8 encoding of any Unicode scalar value except for \r and \n.

This is equivalent to (?uR-s:.) and also [\p{any}--\r\n].

AnyByteExcept(u8)

Matches any byte value except for the u8 given.

This is equivalent to using (?-us:.) with the line terminator set to a particular ASCII byte. (Because of peculiarities in the regex engines, a line terminator must be a single byte. It follows that when UTF-8 mode is enabled, this single byte must also be a Unicode scalar value. That is, ti must be ASCII.)

(This and AnyByteExceptLF both exist because of legacy reasons. AnyByteExceptLF will be dropped in the next breaking change release.)

AnyByteExceptLF

Matches any byte value except for \n.

This is equivalent to (?-su:.) and also (?-u:[[\x00-\xFF]--\n]).

AnyByteExceptCRLF

Matches any byte value except for \r and \n.

This is equivalent to (?R-su:.) and also (?-u:[[\x00-\xFF]--\r\n]).

Implementations

impl Clone for Dot

fn clone(self: &Self) -> Dot

impl Copy for Dot

impl Debug for Dot

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for Dot

impl Freeze for Dot

impl PartialEq for Dot

fn eq(self: &Self, other: &Dot) -> bool

impl RefUnwindSafe for Dot

impl Send for Dot

impl StructuralPartialEq for Dot

impl Sync for Dot

impl Unpin for Dot

impl UnsafeUnpin for Dot

impl UnwindSafe for Dot

impl<T> Any for Dot

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Dot

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Dot

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Dot

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Dot

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for Dot

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Dot

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Dot

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Dot

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>