Struct ClassBytesIter

struct ClassBytesIter<'a>(_)

An iterator over all ranges in a byte character class.

The lifetime 'a refers to the lifetime of the underlying class.

Implementations

impl<'a> Debug for ClassBytesIter<'a>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'a> Freeze for ClassBytesIter<'a>

impl<'a> Iterator for ClassBytesIter<'a>

fn next(self: &mut Self) -> Option<&'a ClassBytesRange>

impl<'a> RefUnwindSafe for ClassBytesIter<'a>

impl<'a> Send for ClassBytesIter<'a>

impl<'a> Sync for ClassBytesIter<'a>

impl<'a> Unpin for ClassBytesIter<'a>

impl<'a> UnsafeUnpin for ClassBytesIter<'a>

impl<'a> UnwindSafe for ClassBytesIter<'a>

impl<I> IntoIterator for ClassBytesIter<'a>

fn into_iter(self: Self) -> I

impl<T> Any for ClassBytesIter<'a>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for ClassBytesIter<'a>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for ClassBytesIter<'a>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for ClassBytesIter<'a>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for ClassBytesIter<'a>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for ClassBytesIter<'a>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for ClassBytesIter<'a>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>