Struct regex_syntax::hir::Group [−][src]
The high-level intermediate representation for a group.
This represents one of three possible group types:
- A non-capturing group (e.g.,
(?:expr)). - A capturing group (e.g.,
(expr)). - A named capturing group (e.g.,
(?P<name>expr)).
Fields
kind: GroupKindThe kind of this group. If it is a capturing group, then the kind contains the capture group index (and the name, if it is a named group).
hir: Box<Hir>The expression inside the capturing group, which may be empty.