Struct UnicodeWordError
struct UnicodeWordError(_)
An error that occurs when the Unicode-aware \w class is unavailable.
This error can occur when the data tables necessary for the Unicode aware
Perl character class \w are unavailable. This only occurs when the
unicode-perl feature is disabled. (The feature is enabled by default.)
Implementations
impl Debug for UnicodeWordError
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for UnicodeWordError
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Error for UnicodeWordError
impl Freeze for UnicodeWordError
impl RefUnwindSafe for UnicodeWordError
impl Send for UnicodeWordError
impl Sync for UnicodeWordError
impl Unpin for UnicodeWordError
impl UnsafeUnpin for UnicodeWordError
impl UnwindSafe for UnicodeWordError
impl<T> Any for UnicodeWordError
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for UnicodeWordError
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for UnicodeWordError
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for UnicodeWordError
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToString for UnicodeWordError
fn to_string(self: &Self) -> String
impl<T, U> Into for UnicodeWordError
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for UnicodeWordError
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for UnicodeWordError
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>