Enum ClassSetBinaryOpKind
enum ClassSetBinaryOpKind
The type of a Unicode character class set operation.
Note that this doesn't explicitly represent union since there is no explicit union operator. Concatenation inside a character class corresponds to the union operation.
Variants
-
Intersection The intersection of two sets, e.g.,
\pN&&[a-z].-
Difference The difference of two sets, e.g.,
\pN--[0-9].-
SymmetricDifference The symmetric difference of two sets. The symmetric difference is the set of elements belonging to one but not both sets. e.g.,
[\pL~~[:ascii:]].
Implementations
impl Clone for ClassSetBinaryOpKind
fn clone(self: &Self) -> ClassSetBinaryOpKind
impl Copy for ClassSetBinaryOpKind
impl Debug for ClassSetBinaryOpKind
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for ClassSetBinaryOpKind
impl Freeze for ClassSetBinaryOpKind
impl PartialEq for ClassSetBinaryOpKind
fn eq(self: &Self, other: &ClassSetBinaryOpKind) -> bool
impl RefUnwindSafe for ClassSetBinaryOpKind
impl Send for ClassSetBinaryOpKind
impl StructuralPartialEq for ClassSetBinaryOpKind
impl Sync for ClassSetBinaryOpKind
impl Unpin for ClassSetBinaryOpKind
impl UnsafeUnpin for ClassSetBinaryOpKind
impl UnwindSafe for ClassSetBinaryOpKind
impl<T> Any for ClassSetBinaryOpKind
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ClassSetBinaryOpKind
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ClassSetBinaryOpKind
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for ClassSetBinaryOpKind
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for ClassSetBinaryOpKind
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for ClassSetBinaryOpKind
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for ClassSetBinaryOpKind
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ClassSetBinaryOpKind
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ClassSetBinaryOpKind
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>