Enum ClassSetItem
enum ClassSetItem
A single component of a character class set.
Variants
-
Empty(Span) An empty item.
Note that a bracketed character class cannot contain a single empty item. Empty items can appear when using one of the binary operators. For example,
[&&]is the intersection of two empty classes.-
Literal(Literal) A single literal.
-
Range(ClassSetRange) A range between two literals.
-
Ascii(ClassAscii) An ASCII character class, e.g.,
[:alnum:]or[:punct:].-
Unicode(ClassUnicode) A Unicode character class, e.g.,
\pLor\p{Greek}.-
Perl(ClassPerl) A perl character class, e.g.,
\dor\W.-
Bracketed(alloc::boxed::Box<ClassBracketed>) A bracketed character class set, which may contain zero or more character ranges and/or zero or more nested classes. e.g.,
[a-zA-Z\pL].-
Union(ClassSetUnion) A union of items.
Implementations
impl ClassSetItem
fn span(self: &Self) -> &SpanReturn the span of this character class set item.
impl Clone for ClassSetItem
fn clone(self: &Self) -> ClassSetItem
impl Debug for ClassSetItem
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for ClassSetItem
impl Freeze for ClassSetItem
impl PartialEq for ClassSetItem
fn eq(self: &Self, other: &ClassSetItem) -> bool
impl RefUnwindSafe for ClassSetItem
impl Send for ClassSetItem
impl StructuralPartialEq for ClassSetItem
impl Sync for ClassSetItem
impl Unpin for ClassSetItem
impl UnsafeUnpin for ClassSetItem
impl UnwindSafe for ClassSetItem
impl<T> Any for ClassSetItem
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ClassSetItem
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ClassSetItem
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for ClassSetItem
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for ClassSetItem
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for ClassSetItem
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for ClassSetItem
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ClassSetItem
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ClassSetItem
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>