Enum HexLiteralKind
enum HexLiteralKind
The type of a Unicode hex literal.
Note that all variants behave the same when used with brackets. They only differ when used without brackets in the number of hex digits that must follow.
Variants
-
X A
\xprefix. When used without brackets, this form is limited to two digits.-
UnicodeShort A
\uprefix. When used without brackets, this form is limited to four digits.-
UnicodeLong A
\Uprefix. When used without brackets, this form is limited to eight digits.
Implementations
impl HexLiteralKind
fn digits(self: &Self) -> u32The number of digits that must be used with this literal form when used without brackets. When used with brackets, there is no restriction on the number of digits.
impl Clone for HexLiteralKind
fn clone(self: &Self) -> HexLiteralKind
impl Debug for HexLiteralKind
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for HexLiteralKind
impl Freeze for HexLiteralKind
impl PartialEq for HexLiteralKind
fn eq(self: &Self, other: &HexLiteralKind) -> bool
impl RefUnwindSafe for HexLiteralKind
impl Send for HexLiteralKind
impl StructuralPartialEq for HexLiteralKind
impl Sync for HexLiteralKind
impl Unpin for HexLiteralKind
impl UnsafeUnpin for HexLiteralKind
impl UnwindSafe for HexLiteralKind
impl<T> Any for HexLiteralKind
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for HexLiteralKind
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for HexLiteralKind
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for HexLiteralKind
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for HexLiteralKind
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for HexLiteralKind
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for HexLiteralKind
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for HexLiteralKind
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for HexLiteralKind
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>