Struct Literal
struct Literal { ... }
A single literal expression.
A literal corresponds to a single Unicode scalar value. Literals may be
represented in their literal form, e.g., a or in their escaped form,
e.g., \x61.
Fields
span: SpanThe span of this literal.
kind: LiteralKindThe kind of this literal.
c: charThe Unicode scalar value corresponding to this literal.
Implementations
impl Literal
fn byte(self: &Self) -> Option<u8>If this literal was written as a
\xhex escape, then this returns the corresponding byte value. Otherwise, this returnsNone.
impl Clone for Literal
fn clone(self: &Self) -> Literal
impl Debug for Literal
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for Literal
impl Freeze for Literal
impl PartialEq for Literal
fn eq(self: &Self, other: &Literal) -> bool
impl RefUnwindSafe for Literal
impl Send for Literal
impl StructuralPartialEq for Literal
impl Sync for Literal
impl Unpin for Literal
impl UnsafeUnpin for Literal
impl UnwindSafe for Literal
impl<T> Any for Literal
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Literal
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Literal
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Literal
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Literal
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Literal
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Literal
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Literal
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Literal
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>