Struct regex_syntax::ast::SetFlags [−][src]
A group of flags that is not applied to a particular regular expression.
Fields
span: SpanThe span of these flags, including the grouping parentheses.
flags: FlagsThe actual sequence of flags.