Function is_word_byte
fn is_word_byte(c: u8) -> bool
Returns true if and only if the given character is an ASCII word character.
An ASCII word character is defined by the following character class:
[_0-9a-zA-Z].
is_word_bytefn is_word_byte(c: u8) -> bool
Returns true if and only if the given character is an ASCII word character.
An ASCII word character is defined by the following character class:
[_0-9a-zA-Z].