Dot

Enum Dot 

#[non_exhaustive]
pub enum Dot { AnyChar, AnyByte, AnyCharExcept(char), AnyCharExceptLF, AnyCharExceptCRLF, AnyByteExcept(u8), AnyByteExceptLF, AnyByteExceptCRLF, }
A type describing the different flavors of ..

This type is meant to be used with Hir::dot, which is a convenience routine for building HIR values derived from the . regex.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


AnyChar

Matches the UTF-8 encoding of any Unicode scalar value.

This is equivalent to (?su:.) and also \p{any}.



AnyByte

Matches any byte value.

This is equivalent to (?s-u:.) and also (?-u:[\x00-\xFF]).



AnyCharExcept(char)

Matches the UTF-8 encoding of any Unicode scalar value except for the char given.

This is equivalent to using (?u-s:.) with the line terminator set to a particular ASCII byte. (Because of peculiarities in the regex engines, a line terminator must be a single byte. It follows that when UTF-8 mode is enabled, this single byte must also be a Unicode scalar value. That is, ti must be ASCII.)

(This and AnyCharExceptLF both exist because of legacy reasons. AnyCharExceptLF will be dropped in the next breaking change release.)



AnyCharExceptLF

Matches the UTF-8 encoding of any Unicode scalar value except for \n.

This is equivalent to (?u-s:.) and also [\p{any}--\n].



AnyCharExceptCRLF

Matches the UTF-8 encoding of any Unicode scalar value except for \r and \n.

This is equivalent to (?uR-s:.) and also [\p{any}--\r\n].



AnyByteExcept(u8)

Matches any byte value except for the u8 given.

This is equivalent to using (?-us:.) with the line terminator set to a particular ASCII byte. (Because of peculiarities in the regex engines, a line terminator must be a single byte. It follows that when UTF-8 mode is enabled, this single byte must also be a Unicode scalar value. That is, ti must be ASCII.)

(This and AnyByteExceptLF both exist because of legacy reasons. AnyByteExceptLF will be dropped in the next breaking change release.)



AnyByteExceptLF

Matches any byte value except for \n.

This is equivalent to (?-su:.) and also (?-u:[[\x00-\xFF]--\n]).



AnyByteExceptCRLF

Matches any byte value except for \r and \n.

This is equivalent to (?R-su:.) and also (?-u:[[\x00-\xFF]--\r\n]).