Enum ErrorKind
enum ErrorKind
The type of an error that occurred while building an Hir.
This error type is marked as non_exhaustive. This means that adding a
new variant is not considered a breaking change.
Variants
-
UnicodeNotAllowed This error occurs when a Unicode feature is used when Unicode support is disabled. For example
(?-u:\pL)would trigger this error.-
InvalidUtf8 This error occurs when translating a pattern that could match a byte sequence that isn't UTF-8 and
utf8was enabled.-
InvalidLineTerminator This error occurs when one uses a non-ASCII byte for a line terminator, but where Unicode mode is enabled and UTF-8 mode is disabled.
-
UnicodePropertyNotFound This occurs when an unrecognized Unicode property name could not be found.
-
UnicodePropertyValueNotFound This occurs when an unrecognized Unicode property value could not be found.
-
UnicodePerlClassNotFound This occurs when a Unicode-aware Perl character class (
\w,\sor\d) could not be found. This can occur when theunicode-perlcrate feature is not enabled.This occurs when the Unicode simple case mapping tables are not available, and the regular expression required Unicode aware case insensitivity.
Implementations
impl Clone for ErrorKind
fn clone(self: &Self) -> ErrorKind
impl Debug for ErrorKind
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for ErrorKind
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for ErrorKind
impl Freeze for ErrorKind
impl PartialEq for ErrorKind
fn eq(self: &Self, other: &ErrorKind) -> bool
impl RefUnwindSafe for ErrorKind
impl Send for ErrorKind
impl StructuralPartialEq for ErrorKind
impl Sync for ErrorKind
impl Unpin for ErrorKind
impl UnsafeUnpin for ErrorKind
impl UnwindSafe for ErrorKind
impl<T> Any for ErrorKind
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ErrorKind
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ErrorKind
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for ErrorKind
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for ErrorKind
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for ErrorKind
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for ErrorKind
fn to_string(self: &Self) -> String
impl<T, U> Into for ErrorKind
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ErrorKind
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ErrorKind
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>