Enum ExtractKind

enum ExtractKind

The kind of literals to extract from an Hir expression.

The default extraction kind is Prefix.

Variants

Prefix

Extracts only prefix literals from a regex.

Suffix

Extracts only suffix literals from a regex.

Note that the sequence returned by suffix literals currently may not correctly represent leftmost-first or "preference" order match semantics.

Implementations

impl ExtractKind

fn is_prefix(self: &Self) -> bool

Returns true if this kind is the Prefix variant.

fn is_suffix(self: &Self) -> bool

Returns true if this kind is the Suffix variant.

impl Clone for ExtractKind

fn clone(self: &Self) -> ExtractKind

impl Debug for ExtractKind

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Default for ExtractKind

fn default() -> ExtractKind

impl Freeze for ExtractKind

impl RefUnwindSafe for ExtractKind

impl Send for ExtractKind

impl Sync for ExtractKind

impl Unpin for ExtractKind

impl UnsafeUnpin for ExtractKind

impl UnwindSafe for ExtractKind

impl<T> Any for ExtractKind

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for ExtractKind

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for ExtractKind

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for ExtractKind

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for ExtractKind

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for ExtractKind

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for ExtractKind

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for ExtractKind

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for ExtractKind

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>