Struct CaseFoldError
struct CaseFoldError(_)
An error that occurs when Unicode-aware simple case folding fails.
This error can occur when the case mapping tables necessary for Unicode
aware case folding are unavailable. This only occurs when the
unicode-case feature is disabled. (The feature is enabled by default.)
Implementations
impl Debug for CaseFoldError
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for CaseFoldError
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Error for CaseFoldError
impl Freeze for CaseFoldError
impl RefUnwindSafe for CaseFoldError
impl Send for CaseFoldError
impl Sync for CaseFoldError
impl Unpin for CaseFoldError
impl UnsafeUnpin for CaseFoldError
impl UnwindSafe for CaseFoldError
impl<T> Any for CaseFoldError
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for CaseFoldError
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for CaseFoldError
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for CaseFoldError
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToString for CaseFoldError
fn to_string(self: &Self) -> String
impl<T, U> Into for CaseFoldError
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for CaseFoldError
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for CaseFoldError
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>