Struct ClassBytesRange
struct ClassBytesRange { ... }
A single range of characters represented by arbitrary bytes.
The range is closed. That is, the start and end of the range are included in the range.
Implementations
impl ClassBytesRange
fn new(start: u8, end: u8) -> ClassBytesRangeCreate a new byte range for a character class.
The returned range is always in a canonical form. That is, the range returned always satisfies the invariant that
start <= end.fn start(self: &Self) -> u8Return the start of this range.
The start of a range is always less than or equal to the end of the range.
fn end(self: &Self) -> u8Return the end of this range.
The end of a range is always greater than or equal to the start of the range.
fn len(self: &Self) -> usizeReturns the number of bytes in this range.
impl Clone for ClassBytesRange
fn clone(self: &Self) -> ClassBytesRange
impl Copy for ClassBytesRange
impl Debug for ClassBytesRange
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Default for ClassBytesRange
fn default() -> ClassBytesRange
impl Eq for ClassBytesRange
impl Freeze for ClassBytesRange
impl Ord for ClassBytesRange
fn cmp(self: &Self, other: &ClassBytesRange) -> Ordering
impl PartialEq for ClassBytesRange
fn eq(self: &Self, other: &ClassBytesRange) -> bool
impl PartialOrd for ClassBytesRange
fn partial_cmp(self: &Self, other: &ClassBytesRange) -> Option<Ordering>
impl RefUnwindSafe for ClassBytesRange
impl Send for ClassBytesRange
impl StructuralPartialEq for ClassBytesRange
impl Sync for ClassBytesRange
impl Unpin for ClassBytesRange
impl UnsafeUnpin for ClassBytesRange
impl UnwindSafe for ClassBytesRange
impl<T> Any for ClassBytesRange
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ClassBytesRange
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ClassBytesRange
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for ClassBytesRange
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for ClassBytesRange
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for ClassBytesRange
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for ClassBytesRange
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ClassBytesRange
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ClassBytesRange
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>