Struct ClassUnicode
struct ClassUnicode { ... }
A set of characters represented by Unicode scalar values.
Implementations
impl ClassUnicode
fn new<I>(ranges: I) -> ClassUnicode where I: IntoIterator<Item = ClassUnicodeRange>Create a new class from a sequence of ranges.
The given ranges do not need to be in any specific order, and ranges may overlap. Ranges will automatically be sorted into a canonical non-overlapping order.
fn empty() -> ClassUnicodeCreate a new class with no ranges.
An empty class matches nothing. That is, it is equivalent to
Hir::fail.fn push(self: &mut Self, range: ClassUnicodeRange)Add a new range to this set.
fn iter(self: &Self) -> ClassUnicodeIter<'_>Return an iterator over all ranges in this class.
The iterator yields ranges in ascending order.
fn ranges(self: &Self) -> &[ClassUnicodeRange]Return the underlying ranges as a slice.
fn case_fold_simple(self: &mut Self)Expand this character class such that it contains all case folded characters, according to Unicode's "simple" mapping. For example, if this class consists of the range
a-z, then applying case folding will result in the class containing both the rangesa-zandA-Z.Panics
This routine panics when the case mapping data necessary for this routine to complete is unavailable. This occurs when the
unicode-casefeature is not enabled.Callers should prefer using
try_case_fold_simpleinstead, which will return an error instead of panicking.fn try_case_fold_simple(self: &mut Self) -> Result<(), CaseFoldError>Expand this character class such that it contains all case folded characters, according to Unicode's "simple" mapping. For example, if this class consists of the range
a-z, then applying case folding will result in the class containing both the rangesa-zandA-Z.Error
This routine returns an error when the case mapping data necessary for this routine to complete is unavailable. This occurs when the
unicode-casefeature is not enabled.fn negate(self: &mut Self)Negate this character class.
For all
cwherecis a Unicode scalar value, ifcwas in this set, then it will not be in this set after negation.fn union(self: &mut Self, other: &ClassUnicode)Union this character class with the given character class, in place.
fn intersect(self: &mut Self, other: &ClassUnicode)Intersect this character class with the given character class, in place.
fn difference(self: &mut Self, other: &ClassUnicode)Subtract the given character class from this character class, in place.
fn symmetric_difference(self: &mut Self, other: &ClassUnicode)Compute the symmetric difference of the given character classes, in place.
This computes the symmetric difference of two character classes. This removes all elements in this class that are also in the given class, but all adds all elements from the given class that aren't in this class. That is, the class will contain all elements in either class, but will not contain any elements that are in both classes.
fn is_ascii(self: &Self) -> boolReturns true if and only if this character class will either match nothing or only ASCII bytes. Stated differently, this returns false if and only if this class contains a non-ASCII codepoint.
fn minimum_len(self: &Self) -> Option<usize>Returns the length, in bytes, of the smallest string matched by this character class.
Returns
Nonewhen the class is empty.fn maximum_len(self: &Self) -> Option<usize>Returns the length, in bytes, of the longest string matched by this character class.
Returns
Nonewhen the class is empty.fn literal(self: &Self) -> Option<Vec<u8>>If this class consists of exactly one codepoint, then return it as a literal byte string.
If this class is empty or contains more than one codepoint, then
Noneis returned.fn to_byte_class(self: &Self) -> Option<ClassBytes>If this class consists of only ASCII ranges, then return its corresponding and equivalent byte class.
impl Clone for ClassUnicode
fn clone(self: &Self) -> ClassUnicode
impl Debug for ClassUnicode
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for ClassUnicode
impl Freeze for ClassUnicode
impl PartialEq for ClassUnicode
fn eq(self: &Self, other: &ClassUnicode) -> bool
impl RefUnwindSafe for ClassUnicode
impl Send for ClassUnicode
impl StructuralPartialEq for ClassUnicode
impl Sync for ClassUnicode
impl Unpin for ClassUnicode
impl UnsafeUnpin for ClassUnicode
impl UnwindSafe for ClassUnicode
impl<T> Any for ClassUnicode
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ClassUnicode
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ClassUnicode
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for ClassUnicode
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for ClassUnicode
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for ClassUnicode
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for ClassUnicode
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ClassUnicode
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ClassUnicode
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>