Struct ClassUnicodeRange

struct ClassUnicodeRange { ... }

A single range of characters represented by Unicode scalar values.

The range is closed. That is, the start and end of the range are included in the range.

Implementations

impl ClassUnicodeRange

fn new(start: char, end: char) -> ClassUnicodeRange

Create a new Unicode scalar value range for a character class.

The returned range is always in a canonical form. That is, the range returned always satisfies the invariant that start <= end.

fn start(self: &Self) -> char

Return the start of this range.

The start of a range is always less than or equal to the end of the range.

fn end(self: &Self) -> char

Return the end of this range.

The end of a range is always greater than or equal to the start of the range.

fn len(self: &Self) -> usize

Returns the number of codepoints in this range.

impl Clone for ClassUnicodeRange

fn clone(self: &Self) -> ClassUnicodeRange

impl Copy for ClassUnicodeRange

impl Debug for ClassUnicodeRange

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Default for ClassUnicodeRange

fn default() -> ClassUnicodeRange

impl Eq for ClassUnicodeRange

impl Freeze for ClassUnicodeRange

impl Ord for ClassUnicodeRange

fn cmp(self: &Self, other: &ClassUnicodeRange) -> Ordering

impl PartialEq for ClassUnicodeRange

fn eq(self: &Self, other: &ClassUnicodeRange) -> bool

impl PartialOrd for ClassUnicodeRange

fn partial_cmp(self: &Self, other: &ClassUnicodeRange) -> Option<Ordering>

impl RefUnwindSafe for ClassUnicodeRange

impl Send for ClassUnicodeRange

impl StructuralPartialEq for ClassUnicodeRange

impl Sync for ClassUnicodeRange

impl Unpin for ClassUnicodeRange

impl UnsafeUnpin for ClassUnicodeRange

impl UnwindSafe for ClassUnicodeRange

impl<T> Any for ClassUnicodeRange

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for ClassUnicodeRange

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for ClassUnicodeRange

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for ClassUnicodeRange

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for ClassUnicodeRange

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for ClassUnicodeRange

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for ClassUnicodeRange

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for ClassUnicodeRange

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for ClassUnicodeRange

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>