Struct Utf8Range
struct Utf8Range { ... }
A single inclusive range of UTF-8 bytes.
Fields
start: u8Start of byte range (inclusive).
end: u8End of byte range (inclusive).
Implementations
impl Utf8Range
fn matches(self: &Self, b: u8) -> boolReturns true if and only if the given byte is in this range.
impl Clone for Utf8Range
fn clone(self: &Self) -> Utf8Range
impl Copy for Utf8Range
impl Debug for Utf8Range
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for Utf8Range
impl Freeze for Utf8Range
impl Ord for Utf8Range
fn cmp(self: &Self, other: &Utf8Range) -> Ordering
impl PartialEq for Utf8Range
fn eq(self: &Self, other: &Utf8Range) -> bool
impl PartialOrd for Utf8Range
fn partial_cmp(self: &Self, other: &Utf8Range) -> Option<Ordering>
impl RefUnwindSafe for Utf8Range
impl Send for Utf8Range
impl StructuralPartialEq for Utf8Range
impl Sync for Utf8Range
impl Unpin for Utf8Range
impl UnsafeUnpin for Utf8Range
impl UnwindSafe for Utf8Range
impl<T> Any for Utf8Range
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Utf8Range
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Utf8Range
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Utf8Range
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Utf8Range
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Utf8Range
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Utf8Range
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Utf8Range
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Utf8Range
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>